# Copyright (C) 2019 X2Go Project - https://wiki.x2go.org
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the
# Free Software Foundation, Inc.,
# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Copyright (C) 2019 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>

# This file is not part of LTSP, https://ltsp.github.io, but extends it

# On X2Go Mini Desktop Thin Clients, the display manager (LightDM) gets
# configured via the x2gothinclient-minidesktop package and does not require
# tweaking by LTSP.
# In fact, the LTSP display manager tweaks break the way the X2Go TCE adapts
# the LightDM configuration. So let's disable the display_manager_main()
# function of LTSP, entirely.

display_manager_main() {
    return 0
}
